#!/usr/bin/env python3

from fastimer.fastimer import main

if __name__ == "__main__":
    main()
